"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Devices = void 0;
const tslib_1 = require("tslib");
const untils_1 = require("../untils");
const Constants = (0, tslib_1.__importStar)(require("./constants"));
class Devices {
    constructor() {
        this.request = (path, method, data) => (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return (0, untils_1.requestApi)({ path, method, data });
        });
        this.controlDeviceData = (device, data) => (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const params = Object.assign({}, data);
            yield this.request(`/devices/${device.deviceId}/desired?productId=${device.productId}`, Constants.HTTP_METHOD_POST, params);
        });
        this.getDeviceList = () => (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const list = yield this.request('/mine/devices', Constants.HTTP_METHOD_GET);
            let devicesRes = {
                count: 0,
                deviceList: []
            };
            if (list.deviceList.length > 0) {
                let deviceIds = 'productId=newProductId';
                list.deviceList.forEach((device) => {
                    deviceIds += `&deviceIds=${device.deviceId}`;
                });
                devicesRes = yield this.request(`/devices?${deviceIds}`, Constants.HTTP_METHOD_GET);
            }
            return {
                count: devicesRes.count,
                deviceList: devicesRes.deviceList.map(device => ({
                    deviceId: device.id,
                    deviceName: `${device.productId}/${device.id}`,
                    productId: device.productId,
                    iconUrl: device.iconUrl,
                    online: device.status === 3 ? true : false,
                    aliasName: device.alias || device.name,
                    name: device.name,
                }))
            };
        });
        this.getDeviceData = ({ DeviceId }) => (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const data = yield this.request(`/devices/${DeviceId}/twin`, Constants.HTTP_METHOD_GET);
            return data;
        });
        this.bindDevice = ({ productId, deviceId }) => (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const data = yield this.request('/mine/devices', Constants.HTTP_METHOD_POST, {
                productId, deviceId
            });
            return data;
        });
        this.unbindDevice = ({ productId, deviceId }) => (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const data = yield this.request(`/mine/devices/${deviceId}?productId=${productId}`, Constants.HTTP_METHOD_DELETE);
            return data;
        });
        this.changeDeviceName = ({ productId, deviceId, aliasName }) => (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const data = yield this.request(`devices/${deviceId}`, Constants.HTTP_METHOD_PUT, {
                productId, alias: aliasName
            });
            return data;
        });
    }
}
exports.Devices = Devices;
//# sourceMappingURL=devices.js.map