"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TisvcMqtt = void 0;
const tslib_1 = require("tslib");
const mqttBase_1 = require("./utils/mqttBase");
const event_emitter_for_miniprogram_1 = (0, tslib_1.__importDefault)(require("event-emitter-for-miniprogram"));
const constants_1 = require("../apiProvider/tisvc/constants");
class TisvcMqtt extends event_emitter_for_miniprogram_1.default {
    constructor() {
        super();
        this.mqtt = new mqttBase_1.MqttBase();
    }
    subscribe(deviceIdList) {
        if (deviceIdList.length > 0) {
            const propertyTopic = deviceIdList.map(device => `devices/${device}/twin/patch/reported`);
            const telemetryTopic = deviceIdList.map(device => `devices/${device}/telemetry`);
            const sysTopic = deviceIdList.map(device => `devices/${device}/sys`);
            this.mqtt.subscribe([...propertyTopic, ...telemetryTopic, ...sysTopic]);
            this.onMessage();
        }
    }
    send(topic, message) {
        this.mqtt.publish(topic, message);
    }
    disconnect() {
        this.mqtt.end();
    }
    onMessage() {
        this.mqtt.onMessage((topic, payload) => {
            const dataStr = payload.toString();
            const deviceId = topic.split('/')[1];
            let data = {};
            try {
                const content = JSON.parse(dataStr);
                data = { deviceData: content, deviceId };
            }
            catch (err) {
                return;
            }
            if (topic.indexOf('/telemetry') > -1) {
                console.log('telemetry data', data);
                this.emit(constants_1.iotEventType.TICOS_IOT_EVENT_TELEMETRY, data);
            }
            else if (topic.indexOf('/reported') > -1) {
                console.log('property data', data);
                this.emit(constants_1.iotEventType.TICOS_IOT_EVENT_PROPERTY, data);
            }
            else if (topic.indexOf('/sys') > -1) {
                const statusData = {
                    online: data.status === 3 ? true : false,
                    deviceId: deviceId
                };
                console.log('status change', statusData);
                this.emit(constants_1.iotEventType.TICOS_IOT_STATUS_CHANGE, statusData);
            }
            console.log('mqtt new message', payload);
        });
    }
}
exports.TisvcMqtt = TisvcMqtt;
//# sourceMappingURL=tisvcMqtt.js.map