"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MqttBase = void 0;
const tslib_1 = require("tslib");
const mqtt = require('./mqtt.js');
const env_detect_1 = (0, tslib_1.__importStar)(require("../../apiProvider/tisvc/untils/env"));
class MqttBase {
    constructor() {
        this.initClient();
    }
    initClient() {
        const opt = {
            // clean: true,
            reconnectPeriod: 1000,
            connectTimeout: 30 * 1000,
            clientId: `app${Math.random().toString(16).substring(2)}${new Date().getTime()}`,
            username: 'testuser',
            password: 'testpassword',
            protocol: env_detect_1.isMiniProgram() ? 'wxs' : 'wss'
            // port: 8084,
            // path: '/mqtt',
            // protocol: "wxs",
            // hostname: 'hub.ticos.cn',
        };
        console.log('start mqtt');
        try {
            //ws://mqtt.ticosdev.cc:1883/mqtt
            const client = mqtt.connect(`${env_detect_1.isMiniProgram() ? 'wxs' : 'wss'}://hub.ticos.cn:8084/mqtt`, opt);
            this.mqClient = client;
            client.on('message', (topic, payload) => {
                // const dataStr = payload.toString()
                // let data = {}
                // try{
                //   const content = JSON.parse(dataStr)
                //   data = { ...content}
                // }catch(err){
                //   return
                // }
                // if(topic.indexOf('telemetry')>0){
                //   this.emit(iotEventType.TICOS_IOT_EVENT_TELEMETRY, data)
                // }else if(topic.indexOf('reported') > 0){
                //   this.emit(iotEventType.TICOS_IOT_EVENT_PROPERTY, data)
                // }
                console.log('mqtt new message', payload);
            });
            client.on("connect", () => {
                console.log('mqtt connected');
            });
            client.on("err", (err) => {
                console.log('mqtt error:', err);
            });
            client.on("offline", () => {
                console.log("mqtt connection disconnected");
            });
        }
        catch (err) {
            console.log('mqtt err', err);
        }
    }
    end() {
        this.mqClient.end();
    }
    subscribe(topic) {
        this.mqClient.subscribe(topic, { qos: 0 }, function (error, granted) {
            if (error) {
                console.log(error);
            }
            else {
                console.log('subscribed', granted);
            }
        });
    }
    unsubscribe(topic) {
        this.mqClient.unsubscribe(topic, function (error) {
            if (error) {
                console.log(error);
            }
            else {
                console.log('Unsubscribed');
            }
        });
    }
    publish(topic, message) {
        this.mqClient.publish(topic, message, { qos: 0, retain: false }, function (error) {
            if (error) {
                console.log(error);
            }
            else {
                console.log('Published');
            }
        });
    }
    onMessage(callback) {
        this.mqClient.on('message', function (topic, payload, packet) {
            // payload is Buffer
            callback(topic, payload);
        });
    }
}
exports.MqttBase = MqttBase;
//# sourceMappingURL=mqttBase.js.map