"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatDate = exports.getErrorMsg = exports.fetchAllList = void 0;
const tslib_1 = require("tslib");
const fetchAllList = (fetchFn) => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
    const limit = 100;
    let offset = 0;
    let total = 100;
    let list = new Array();
    while (offset === 0 || list.length < total) {
        const resp = yield fetchFn({ offset, limit });
        if (!resp.list.length)
            return list;
        total = resp.total;
        offset = offset + limit;
        list = list.concat(resp.list);
    }
    return list;
});
exports.fetchAllList = fetchAllList;
const getErrorMsg = (err) => {
    if (!err)
        return;
    let message = '';
    if (typeof err === 'string')
        return err;
    message = err.msg || err.message || err.errMsg || err.Message || '';
    if (message && err.reqId) {
        message += `(${err.reqId})`;
    }
    return message;
};
exports.getErrorMsg = getErrorMsg;
const pad = (str, len) => {
    let paddedString = String(str);
    while (paddedString.length < len) {
        paddedString = `0${paddedString}`;
    }
    return paddedString;
};
/**
 * 格式化时间
 *
 * yyyy-mm-dd HH:MM:ss
 *
 * @param {*} [date]
 * @return {String}
 */
const formatDate = (date) => {
    let dateObj;
    if (date instanceof Date) {
        dateObj = date;
    }
    else if (typeof date === 'number') {
        dateObj = new Date(date);
    }
    else {
        dateObj = null;
    }
    if (!dateObj)
        return '-';
    const d = dateObj.getDate();
    const m = dateObj.getMonth() + 1;
    const y = dateObj.getFullYear();
    const H = dateObj.getHours();
    const M = dateObj.getMinutes();
    const s = dateObj.getSeconds();
    const yyyy = y;
    const mm = pad(m, 2);
    const dd = pad(d, 2);
    const HH = pad(H, 2);
    const MM = pad(M, 2);
    const ss = pad(s, 2);
    return `${yyyy}-${mm}-${dd} ${HH}:${MM}:${ss}`;
};
exports.formatDate = formatDate;
//# sourceMappingURL=utils.js.map